aboutsummaryrefslogtreecommitdiffstats
path: root/include/functions_category.inc.php
diff options
context:
space:
mode:
Diffstat (limited to 'include/functions_category.inc.php')
-rw-r--r--include/functions_category.inc.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/functions_category.inc.php b/include/functions_category.inc.php
index 8113064d6..4ae2b126c 100644
--- a/include/functions_category.inc.php
+++ b/include/functions_category.inc.php
@@ -67,7 +67,7 @@ SELECT ';
$query.= '
FROM '.CATEGORIES_TABLE.' INNER JOIN '.USER_CACHE_CATEGORIES_TABLE.'
ON id = cat_id and user_id = '.$user['id'];
- if ($page['filter_mode'])
+ if ($page['filter_local_mode'])
{
$query.= '
where max_date_last > SUBDATE(
@@ -75,8 +75,8 @@ where max_date_last > SUBDATE(
}
else
{
- // Always expand when filter_mode is activated
- if (!$user['expand'])
+ // Always expand when filter_local_mode is activated
+ if (!$user['expand'] and !$user['filter_global_mode'])
{
$query.= '
WHERE (id_uppercat is NULL';